.. _sb_pair_plot:

============
sb-pair-plot
============

The :class:`CGATReportPlugins.Seaborn.PairPlot` displays
:term:`numerical arrays` as pair plots.

.. report:: Trackers.MultipleColumnDataFullExample
   :render: sb-pair-plot
   :layout: row
   :width: 200

   A pair-plot from a tracker returning multiple columns of data.

.. report:: Trackers.ArrayDataExample
   :render: sb-pair-plot
   :layout: row
   :width: 200

   A pair-plot from a tracker returning multiple columns of data.

Options
-------

:class:`CGATReportPlugins.Seaborn.PairPlot` has no additional
options apart from :ref:`common plot options`. 

